@@ -150,6 +150,8 @@ INSTALLED_APPS = (
     'kombu.transport.django',
     'raven.contrib.django.raven_compat',
     'sentry',
+    'sentry.nodestore',
+    'sentry.search',
     'sentry.plugins.sentry_interface_types',
     'sentry.plugins.sentry_mail',
     'sentry.plugins.sentry_urls',
@@ -194,7 +196,7 @@ AUTHENTICATION_BACKENDS = (
     'sentry.utils.auth.EmailAuthBackend',
 )
 
-SOCIAL_AUTH_USER_MODEL = AUTH_USER_MODEL = 'auth.User'
+SOCIAL_AUTH_USER_MODEL = AUTH_USER_MODEL = 'sentry.User'
 
 SESSION_ENGINE = "django.contrib.sessions.backends.signed_cookies"
 
@@ -230,6 +232,8 @@ SOCIAL_AUTH_PIPELINE = (
 
 SOCIAL_AUTH_CREATE_USERS = True
 
+INITIAL_CUSTOM_USER_MIGRATION = '0108_fix_user'
+
 # Auth engines and the settings required for them to be listed
 AUTH_PROVIDERS = {
     'twitter': ('TWITTER_CONSUMER_KEY', 'TWITTER_CONSUMER_SECRET'),
@@ -272,6 +276,7 @@ CELERY_QUEUES = (
     Queue('events', routing_key='events'),
     Queue('triggers', routing_key='triggers'),
     Queue('update', routing_key='update'),
+    Queue('email', routing_key='email'),
 )
 
 # Disable South in tests as it is sending incorrect create signals
@@ -356,6 +361,7 @@ SENTRY_STATIC_BUNDLES = {
                 "sentry/scripts/lib/jquery.flot.dashes.js",
                 "sentry/scripts/lib/jquery.flot.resize.js",
                 "sentry/scripts/lib/jquery.flot.time.js",
+                "sentry/scripts/lib/jquery.flot.tooltip.js",
                 "sentry/scripts/lib/moment.js",
                 "sentry/scripts/lib/simple-slider.js",
                 "sentry/scripts/lib/json2.js",
@@ -460,11 +466,13 @@ SENTRY_WEB_OPTIONS = {
 # UDP Service
 SENTRY_UDP_HOST = 'localhost'
 SENTRY_UDP_PORT = 9001
+SENTRY_USE_IPV6_UDP = False
 
-# Queue (Kombu)
-SENTRY_QUEUE = {
-    'transport': 'kombu.transport.django.Transport',
-}
+# SMTP Service
+SENTRY_ENABLE_EMAIL_REPLIES = False
+SENTRY_SMTP_HOSTNAME = 'localhost'
+SENTRY_SMTP_HOST = 'localhost'
+SENTRY_SMTP_PORT = 1025
 
 SENTRY_ALLOWED_INTERFACES = set([
     'sentry.interfaces.Exception',
@@ -493,10 +501,6 @@ SENTRY_ALLOW_PUBLIC_PROJECTS = True
 # manually.
 SENTRY_ALLOW_REGISTRATION = True
 
-# Instructs Sentry to utilize it's internal search indexer on all incoming
-# events..
-SENTRY_USE_SEARCH = True
-
 # Enable trend results. These can be expensive and are calculated in real-time.
 # When disabled they will be replaced w/ a default priority sort.
 SENTRY_USE_TRENDING = True
@@ -510,17 +514,36 @@ SENTRY_SCRAPE_JAVASCRIPT_CONTEXT = True
 # Redis connection information (see Nydus documentation)
 SENTRY_REDIS_OPTIONS = {}
 
-# Buffer backend to use
+# Buffer backend
 SENTRY_BUFFER = 'sentry.buffer.Buffer'
 SENTRY_BUFFER_OPTIONS = {}
 
+# Quota backend
 SENTRY_QUOTAS = 'sentry.quotas.Quota'
 SENTRY_QUOTA_OPTIONS = {}
+
 # The default value for project-level quotas
 SENTRY_DEFAULT_MAX_EVENTS_PER_MINUTE = '90%'
+
 # The maximum number of events per minute the system should accept.
 SENTRY_SYSTEM_MAX_EVENTS_PER_MINUTE = 0
 
+# Node storage backend
+SENTRY_NODESTORE = 'sentry.nodestore.django.DjangoNodeStorage'
+SENTRY_NODESTORE_OPTIONS = {}
+
+# Search backend
+SENTRY_SEARCH = 'sentry.search.django.DjangoSearchBackend'
+SENTRY_SEARCH_OPTIONS = {}
+# SENTRY_SEARCH_OPTIONS = {
+#     'urls': ['http://localhost:9200/'],
+#     'timeout': 5,
+# }
+
+# Enable search within the frontend
+SENTRY_USE_SEARCH = True
+# SENTRY_INDEX_SEARCH = SENTRY_USE_SEARCH
+
 SENTRY_RAVEN_JS_URL = 'd3nslu0hdya83q.cloudfront.net/dist/1.0/raven.min.js'
 
 # URI Prefixes for generating DSN URLs
