@@ -8,12 +8,9 @@ sentry.manager
 
 from __future__ import with_statement
 
-from collections import defaultdict
 import datetime
 import hashlib
-import itertools
 import logging
-import re
 import time
 import warnings
 import uuid
@@ -26,7 +23,6 @@ from django.db import models, transaction, IntegrityError
 from django.db.models import Sum
 from django.utils import timezone
 from django.utils.datastructures import SortedDict
-from django.utils.encoding import force_unicode
 
 from raven.utils.encoding import to_string
 from sentry import app
@@ -41,7 +37,7 @@ from sentry.tasks.index import index_event
 from sentry.utils.cache import cache, memoize
 from sentry.utils.dates import get_sql_date_trunc, normalize_datetime
 from sentry.utils.db import get_db_engine, has_charts, attach_foreignkey
-from sentry.utils.safe import safe_execute, trim, trim_dict
+from sentry.utils.safe import safe_execute, trim, trim_dict, trim_frames
 from sentry.utils.strings import strip
 
 logger = logging.getLogger('sentry.errors')
@@ -283,11 +279,13 @@ class GroupManager(BaseManager, ChartMixin):
                     if value:
                         exc_data[key] = trim(value)
                 if exc_data.get('stacktrace'):
+                    trim_frames(exc_data['stacktrace'])
                     for frame in exc_data['stacktrace']['frames']:
                         stack_vars = frame.get('vars', {})
                         trim_dict(stack_vars)
 
         if 'sentry.interfaces.Stacktrace' in data:
+            trim_frames(data['sentry.interfaces.Stacktrace'])
             for frame in data['sentry.interfaces.Stacktrace']['frames']:
                 stack_vars = frame.get('vars', {})
                 trim_dict(stack_vars)
@@ -452,7 +450,7 @@ class GroupManager(BaseManager, ChartMixin):
                 is_sample=is_sample
             )
 
-        if settings.SENTRY_USE_SEARCH:
+        if getattr(settings, 'SENTRY_INDEX_SEARCH', settings.SENTRY_USE_SEARCH):
             index_event.delay(event)
 
         # TODO: move this to the queue
@@ -819,6 +817,14 @@ class InstanceMetaManager(BaseManager):
         self.__dict__.update(state)
         self.__metadata = {}
 
+    def _make_key(self, instance):
+        if isinstance(instance, models.Model):
+            instance_id = instance.pk
+        else:
+            instance_id = instance
+
+        return '%s:%s' % (self.model._meta.db_table, instance_id)
+
     def get_value_bulk(self, instances, key):
         return dict(self.filter(**{
             '%s__in' % self.field_name: instances,
@@ -836,6 +842,7 @@ class InstanceMetaManager(BaseManager):
         if instance.pk not in self.__metadata:
             return
         self.__metadata[instance.pk].pop(key, None)
+        cache.set(self._make_key(instance), self.__metadata[instance.pk])
 
     def set_value(self, instance, key, value):
         inst, created = self.get_or_create(**{
@@ -851,6 +858,7 @@ class InstanceMetaManager(BaseManager):
         if instance.pk not in self.__metadata:
             return
         self.__metadata[instance.pk][key] = value
+        cache.set(self._make_key(instance), self.__metadata[instance.pk])
 
     def get_all_values(self, instance):
         if isinstance(instance, models.Model):
@@ -859,12 +867,16 @@ class InstanceMetaManager(BaseManager):
             instance_id = instance
 
         if instance_id not in self.__metadata:
-            result = dict(
-                (i.key, i.value) for i in
-                self.filter(**{
-                    self.field_name: instance_id,
-                })
-            )
+            cache_key = self._make_key(instance)
+            result = cache.get(cache_key)
+            if result is None:
+                result = dict(
+                    (i.key, i.value) for i in
+                    self.filter(**{
+                        self.field_name: instance_id,
+                    })
+                )
+                cache.add(cache_key, result)
             self.__metadata[instance_id] = result
         return self.__metadata.get(instance_id, {})
 
@@ -949,135 +961,6 @@ class UserOptionManager(BaseManager):
         self.__metadata = {}
 
 
-class SearchDocumentManager(BaseManager):
-    # Words which should not be indexed
-    STOP_WORDS = set(['the', 'of', 'to', 'and', 'a', 'in', 'is', 'it', 'you', 'that'])
-
-    # Do not index any words shorter than this
-    MIN_WORD_LENGTH = 3
-
-    # Consider these characters to be punctuation (they will be replaced with spaces prior to word extraction)
-    PUNCTUATION_CHARS = re.compile('[%s]' % re.escape(".,;:!?@$%^&*()-<>[]{}\\|/`~'\""))
-
-    def _tokenize(self, text):
-        """
-        Given a string, returns a list of tokens.
-        """
-        if not text:
-            return []
-
-        text = self.PUNCTUATION_CHARS.sub(' ', text)
-
-        words = [t[:128].lower() for t in text.split() if len(t) >= self.MIN_WORD_LENGTH and t.lower() not in self.STOP_WORDS]
-
-        return words
-
-    def search(self, project, query, sort_by='score', offset=0, limit=100):
-        tokens = self._tokenize(query)
-
-        if sort_by == 'score':
-            order_by = 'SUM(st.times_seen) / sd.total_events DESC'
-        elif sort_by == 'new':
-            order_by = 'sd.date_added DESC'
-        elif sort_by == 'date':
-            order_by = 'sd.date_changed DESC'
-        else:
-            raise ValueError('sort_by: %r' % sort_by)
-
-        if tokens:
-            token_sql = ' st.token IN (%s) AND ' % \
-                ', '.join('%s' for i in range(len(tokens)))
-        else:
-            token_sql = ' '
-
-        sql = """
-            SELECT sd.*,
-                   SUM(st.times_seen) / sd.total_events as score
-            FROM sentry_searchdocument as sd
-            INNER JOIN sentry_searchtoken as st
-                ON st.document_id = sd.id
-            WHERE %s
-                sd.project_id = %s
-            GROUP BY sd.id, sd.group_id, sd.total_events, sd.date_changed, sd.date_added, sd.project_id, sd.status
-            ORDER BY %s
-            LIMIT %d OFFSET %d
-        """ % (
-            token_sql,
-            project.id,
-            order_by,
-            limit,
-            offset,
-        )
-        params = tokens
-
-        return self.raw(sql, params)
-
-    def index(self, event):
-        from sentry.models import SearchToken
-
-        group = event.group
-        document, created = self.get_or_create(
-            project=event.project,
-            group=group,
-            defaults={
-                'status': group.status,
-                'total_events': 1,
-                'date_added': group.first_seen,
-                'date_changed': group.last_seen,
-            }
-        )
-        if not created:
-            app.buffer.incr(self.model, {
-                'total_events': 1,
-            }, {
-                'id': document.id,
-            }, {
-                'date_changed': group.last_seen,
-                'status': group.status,
-            })
-
-            document.total_events += 1
-            document.date_changed = group.last_seen
-            document.status = group.status
-
-        context = defaultdict(list)
-        for interface in event.interfaces.itervalues():
-            for k, v in interface.get_search_context(event).iteritems():
-                context[k].extend(v)
-
-        context['text'].extend([
-            event.message,
-            event.logger,
-            event.server_name,
-            event.culprit,
-        ])
-
-        token_counts = defaultdict(lambda: defaultdict(int))
-        for field, values in context.iteritems():
-            field = field.lower()
-            if field == 'text':
-                # we only tokenize the base text field
-                values = itertools.chain(*[self._tokenize(force_unicode(v)) for v in values])
-            else:
-                values = [v.lower() for v in values]
-            for value in values:
-                if not value:
-                    continue
-                token_counts[field][value] += 1
-
-        for field, tokens in token_counts.iteritems():
-            for token, count in tokens.iteritems():
-                app.buffer.incr(SearchToken, {
-                    'times_seen': count,
-                }, {
-                    'document': document,
-                    'token': token,
-                    'field': field,
-                })
-
-        return document
-
-
 class TagKeyManager(BaseManager):
     def _get_cache_key(self, project_id):
         return 'filterkey:all:%s' % project_id
