@@ -7,11 +7,16 @@ sentry.utils.javascript
 """
 import time
 
+from collections import defaultdict
+
 from django.core.urlresolvers import reverse
 from django.utils.html import escape
+
 from sentry.app import env
-from sentry.constants import STATUS_RESOLVED
-from sentry.models import Group, GroupBookmark, GroupTagKey, GroupSeen
+from sentry.constants import STATUS_RESOLVED, TAG_LABELS
+from sentry.models import (
+    Group, GroupBookmark, GroupTagKey, GroupSeen, ProjectOption
+)
 from sentry.templatetags.sentry_plugins import get_tags
 from sentry.utils import json
 from sentry.utils.db import attach_foreignkey
@@ -92,18 +97,40 @@ class GroupTransformer(Transformer):
         else:
             historical_data = {}
 
-        user_counts = dict(GroupTagKey.objects.filter(
+        project_list = set(o.project for o in objects)
+        tag_keys = set(['sentry:user'])
+        project_annotations = {}
+        for project in project_list:
+            enabled_annotations = ProjectOption.objects.get_value(
+                project, 'annotations', ['sentry:user'])
+            project_annotations[project] = enabled_annotations
+            tag_keys.update(enabled_annotations)
+
+        annotation_counts = defaultdict(dict)
+        annotation_results = GroupTagKey.objects.filter(
             group__in=objects,
-            key='sentry:user',
-        ).values_list('group', 'values_seen'))
+            key__in=tag_keys,
+        ).values_list('key', 'group', 'values_seen')
+        for key, group_id, values_seen in annotation_results:
+            annotation_counts[key][group_id] = values_seen
 
         for g in objects:
             g.is_bookmarked = g.pk in bookmarks
             g.historical_data = [x[1] for x in historical_data.get(g.id, [])]
-            if user_counts:
-                g.users_seen = user_counts.get(g.id, 0)
             active_date = g.active_at or g.last_seen
             g.has_seen = seen_groups.get(g.id, active_date) > active_date
+            g.annotations = []
+            for key in sorted(tag_keys):
+                if key in project_annotations[project]:
+                    label = TAG_LABELS.get(key, key.replace('_', ' ')).lower() + 's'
+                    try:
+                        value = annotation_counts[key].get(g.id, 0)
+                    except KeyError:
+                        value = 0
+                    g.annotations.append({
+                        'label': label,
+                        'count': value,
+                    })
 
     def localize_datetime(self, dt, request=None):
         if not request:
@@ -136,14 +163,14 @@ class GroupTransformer(Transformer):
             },
             'version': time.time(),
         }
-        if hasattr(obj, 'users_seen'):
-            d['usersSeen'] = obj.users_seen
         if hasattr(obj, 'is_bookmarked'):
             d['isBookmarked'] = obj.is_bookmarked
         if hasattr(obj, 'has_seen'):
             d['hasSeen'] = obj.has_seen
         if hasattr(obj, 'historical_data'):
             d['historicalData'] = obj.historical_data
+        if hasattr(obj, 'annotations'):
+            d['annotations'] = obj.annotations
         if request:
             d['tags'] = list(get_tags(obj, request))
         return d
