@@ -34,33 +34,27 @@ TIMEZONE_CHOICES = _get_timezone_choices()
 
 
 class RegistrationForm(forms.ModelForm):
-    email = forms.EmailField()
-    password = forms.CharField(widget=forms.PasswordInput)
+    username = forms.EmailField(
+        label=_('Email'), max_length=128,
+        widget=forms.TextInput(attrs={'placeholder': 'you@example.com'}))
+    password = forms.CharField(
+        widget=forms.PasswordInput(attrs={'placeholder': 'something super secret'}))
 
     class Meta:
-        fields = ('username', 'email')
+        fields = ('username',)
         model = User
 
-    def clean_email(self):
-        value = self.cleaned_data.get('email')
-        if not value:
-            return
-        # We don't really care about why people think they need multiple User accounts with the same
-        # email address -- dealwithit.jpg
-        if User.objects.filter(email__iexact=value).exists():
-            raise forms.ValidationError(_('An account is already registered with that email address.'))
-        return value
-
     def clean_username(self):
         value = self.cleaned_data.get('username')
         if not value:
             return
         if User.objects.filter(username__iexact=value).exists():
-            raise forms.ValidationError(_('An account is already registered with that username.'))
-        return value
+            raise forms.ValidationError(_('An account is already registered with that email address.'))
+        return value.lower()
 
     def save(self, commit=True):
         user = super(RegistrationForm, self).save(commit=False)
+        user.email = user.username
         user.set_password(self.cleaned_data['password'])
         if commit:
             user.save()
@@ -69,10 +63,18 @@ class RegistrationForm(forms.ModelForm):
 
 class NotificationSettingsForm(forms.Form):
     alert_email = forms.EmailField(help_text=_('Designate an alternative email address to send email notifications to.'), required=False)
-    subscribe_by_default = forms.ChoiceField(choices=(
-        ('1', _('Automatically subscribe to notifications for new projects')),
-        ('0', _('Do not subscribe to notifications for new projects')),
-    ), required=False)
+    subscribe_by_default = forms.ChoiceField(
+        choices=(
+            ('1', _('Automatically subscribe to notifications for new projects')),
+            ('0', _('Do not subscribe to notifications for new projects')),
+        ), required=False,
+        widget=forms.Select(attrs={'class': 'input-xxlarge'}))
+    subscribe_notes = forms.ChoiceField(
+        choices=(
+            ('1', _('Get notified about new notes on events I\'ve seen')),
+            ('0', _('Do not subscribe to note notifications')),
+        ), required=False,
+        widget=forms.Select(attrs={'class': 'input-xxlarge'}))
 
     def __init__(self, user, *args, **kwargs):
         self.user = user
@@ -89,6 +91,12 @@ class NotificationSettingsForm(forms.Form):
             key='subscribe_by_default',
             default='1',
         )
+        self.fields['subscribe_notes'].initial = UserOption.objects.get_value(
+            user=self.user,
+            project=None,
+            key='subscribe_notes',
+            default='1',
+        )
 
     def get_title(self):
         return "General"
@@ -106,6 +114,12 @@ class NotificationSettingsForm(forms.Form):
             key='subscribe_by_default',
             value=self.cleaned_data['subscribe_by_default'],
         )
+        UserOption.objects.set_value(
+            user=self.user,
+            project=None,
+            key='subscribe_notes',
+            value=self.cleaned_data['subscribe_notes'],
+        )
 
 
 class AccountSettingsForm(forms.Form):
@@ -144,17 +158,19 @@ class AccountSettingsForm(forms.Form):
 
 class AppearanceSettingsForm(forms.Form):
     language = forms.ChoiceField(
-        label=_('Language'), choices=LANGUAGES, required=False)
+        label=_('Language'), choices=LANGUAGES, required=False,
+        widget=forms.Select(attrs={'class': 'input-xlarge'}))
     stacktrace_order = forms.ChoiceField(
         label=_('Stacktrace order'), choices=(
             ('-1', _('Default (let Sentry decide)')),
             ('1', _('Most recent call last')),
             ('2', _('Most recent call first')),
         ), help_text=_('Choose the default ordering of frames in stacktraces.'),
-        required=False)
+        required=False,
+        widget=forms.Select(attrs={'class': 'input-xlarge'}))
     timezone = forms.ChoiceField(
         label=_('Time zone'), choices=TIMEZONE_CHOICES, required=False,
-        widget=forms.Select(attrs={'class': 'span4'}))
+        widget=forms.Select(attrs={'class': 'input-xxlarge'}))
 
     def __init__(self, user, *args, **kwargs):
         self.user = user
@@ -219,7 +235,7 @@ class ProjectEmailOptionsForm(forms.Form):
             user, project, 'mail:alert', None)
         if is_enabled is None:
             is_enabled = UserOption.objects.get_value(
-                user, None, 'subscribe_by_default', 1) == 1
+                user, None, 'subscribe_by_default', '1') == '1'
         else:
             is_enabled = bool(is_enabled)
 
